PyXMake Developer Guide: PyXMake.VTL.stm_make.app_pycodac Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Attributes | Protected Member Functions | Static Protected Attributes | List of all members
PyXMake.VTL.stm_make.app_pycodac Class Reference
Inheritance diagram for PyXMake.VTL.stm_make.app_pycodac:

## Public Attributes
| include = VTL.GetIncludeDirectory(PyCODAC.PyCODACPath, self._KEY_OPT),
| dependency = VTL.GetLinkDependency(self._KEY_OPT),
Public Attributes inherited from PyXMake.VTL.stm_make.pyx_app
int | verbose = 0
str | source_path = ''
str | output_file_path = ''
str | mode = "onedir"
| scratch_path = os.getcwd()
| include = None
| dependency = None
Public Attributes inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| verbose

## Protected Member Functions
| _create_command (self)
Protected Member Functions inherited from PyXMake.VTL.stm_make.pyx_app
| _run_command (self, command)
Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _perform_post_actions (self)

## Static Protected Attributes
int | _KEY_OPT = 8
str | _APP_NAME = 'STMLab'
| _INPUT_SCRIPT = GetSourceCode(_KEY_OPT)
Static Protected Attributes inherited from PyXMake.VTL.stm_make.pyx_app
str | _APP_NAME = ''
str | _INPUT_SCRIPT = ""

## Additional Inherited Members
Public Member Functions inherited from PyXMake.VTL.stm_make.pyx_app
| initialize_options (self)
| finalize_options (self)
Public Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| run (self)
Static Public Attributes inherited from PyXMake.VTL.stm_make.pyx_app
str | description = "Compile a stand-alone application using PyInstaller."
list | user_options
Static Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _create_build_dir ()

## Detailed Description

    Runs the application build process using PyCODAC to create runtime for STMLab.

Definition at line 163 of file stm_make.py.

## Member Function Documentation

## ◆ _create_command()

PyXMake.VTL.stm_make.app_pycodac._create_command | ( |  | self | ) |
| protected

Reimplemented from PyXMake.VTL.stm_make._BaseCommandRunner.

Definition at line 174 of file stm_make.py.

## Member Data Documentation

## ◆ _APP_NAME

str PyXMake.VTL.stm_make.app_pycodac._APP_NAME = 'STMLab'
| staticprotected

Definition at line 171 of file stm_make.py.

## ◆ _INPUT_SCRIPT

PyXMake.VTL.stm_make.app_pycodac._INPUT_SCRIPT = GetSourceCode(_KEY_OPT)
| staticprotected

Definition at line 172 of file stm_make.py.

## ◆ _KEY_OPT

int PyXMake.VTL.stm_make.app_pycodac._KEY_OPT = 8
| staticprotected

Definition at line 170 of file stm_make.py.

## ◆ dependency

PyXMake.VTL.stm_make.app_pycodac.dependency = VTL.GetLinkDependency(self._KEY_OPT),

Definition at line 180 of file stm_make.py.

## ◆ include

PyXMake.VTL.stm_make.app_pycodac.include = VTL.GetIncludeDirectory(PyCODAC.PyCODACPath, self._KEY_OPT),

Definition at line 179 of file stm_make.py.

The documentation for this class was generated from the following file:

- src/PyXMake/VTL/stm_make.py